@@ -5,7 +5,7 @@ use warnings;
 use Email::Valid;
 use Time::Piece;
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 use base 'Exporter';
 our @EXPORT= qw/NOT_BLANK INT ASCII STRING DECIMAL EMAIL DATETIME DATE TIME TINYINT URL LENGTH BETWEEN DIGIT_LENGTH/;
@@ -25,6 +25,16 @@ sub INT{
     $s =~ m/^\d+$|^-\d+$/;
 }
 
+sub BOOLEAN{
+    my $s = shift;
+    $s = lc $s;
+    
+    my $allow_strings = {
+        map{$_ => 1}qw/1 0 true false yes no /
+    };
+    return $allow_strings->{$s}
+}
+
 sub ASCII{
     my $s = shift;
     return 1 unless $s;
@@ -157,7 +167,7 @@ FormValidator::Simple::Struct::Regex - Plugin for FormValidator::Simple::Struct
 
 =head1 VERSION
 
-This document describes FormValidator::Simple::Struct::Regex version 0.16.
+This document describes FormValidator::Simple::Struct::Regex version 0.17.
 
 =head1 SYNOPSIS
 
